@@ -1,30 +1,18 @@
-/*  This file is part of the KDE project
-    Copyright (C) 2008 Rafael Fernández López <ereslibre@kde.org>
-    Copyright (C) 2007 Kevin Ottens <ervin@kde.org>
-
-    This library is free software; you can redistribute it and/or
-    modify it under the terms of the GNU Library General Public
-    License version 2 as published by the Free Software Foundation.
-
-    This library is distributed in the hope that it will be useful,
-    but WITHOUT ANY WARRANTY; without even the implied warranty of
-    MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
-    Library General Public License for more details.
-
-    You should have received a copy of the GNU Library General Public License
-    along with this library; see the file COPYING.LIB.  If not, write to
-    the Free Software Foundation, Inc., 51 Franklin Street, Fifth Floor,
-    Boston, MA 02110-1301, USA.
+/*
+    This file is part of the KDE project
+    SPDX-FileCopyrightText: 2008 Rafael Fernández López <ereslibre@kde.org>
+    SPDX-FileCopyrightText: 2007 Kevin Ottens <ervin@kde.org>
 
+    SPDX-License-Identifier: LGPL-2.0-only
 */
 
 #include "kuiserverjobtracker.h"
 #include "kuiserverjobtracker_p.h"
 
-#include "jobviewiface.h"
 #include "debug.h"
+#include "jobviewiface.h"
 
-#include <kjob.h>
+#include <KJob>
 
 #include <QApplication>
 #include <QDBusConnection>
@@ -73,16 +61,15 @@ void KUiServerJobTracker::Private::updateDestUrl(KJob *job, org::kde::JobViewV2
 }
 
 KUiServerJobTracker::KUiServerJobTracker(QObject *parent)
-    : KJobTrackerInterface(parent), d(new Private(this))
+    : KJobTrackerInterface(parent)
+    , d(new Private(this))
 {
-
 }
 
 KUiServerJobTracker::~KUiServerJobTracker()
 {
     if (!d->progressJobView.isEmpty()) {
-        qWarning() << "A KUiServerJobTracker instance contains"
-                   << d->progressJobView.size() << "stalled jobs";
+        qWarning() << "A KUiServerJobTracker instance contains" << d->progressJobView.size() << "stalled jobs";
     }
 
     qDeleteAll(d->progressJobView);
@@ -121,33 +108,26 @@ void KUiServerJobTracker::registerJob(KJob *job)
     }
 
     QPointer<KJob> jobWatch = job;
-    QDBusReply<QDBusObjectPath> reply = serverProxy()->uiserver()->requestView(appName,
-                                        programIconName,
-                                        job->capabilities());
+    QDBusReply<QDBusObjectPath> reply = serverProxy()->uiserver()->requestView(appName, programIconName, job->capabilities());
 
     // If we got a valid reply, register the interface for later usage.
     if (reply.isValid()) {
-        org::kde::JobViewV2 *jobView = new org::kde::JobViewV2(QStringLiteral("org.kde.JobViewServer"),
-                reply.value().path(),
-                QDBusConnection::sessionBus());
+        org::kde::JobViewV2 *jobView = new org::kde::JobViewV2(QStringLiteral("org.kde.JobViewServer"), reply.value().path(), QDBusConnection::sessionBus());
         if (!jobWatch) {
-            //qCDebug(KJOBWIDGETS) << "deleted out from under us when asking the server proxy for the view";
+            // qCDebug(KJOBWIDGETS) << "deleted out from under us when asking the server proxy for the view";
             jobView->terminate(QString());
             delete jobView;
             return;
         }
 
-        QObject::connect(jobView, SIGNAL(cancelRequested()),
-                         this, SLOT(_k_killJob()));
-        QObject::connect(jobView, &org::kde::JobViewV2::suspendRequested,
-                         job, &KJob::suspend);
-        QObject::connect(jobView, &org::kde::JobViewV2::resumeRequested,
-                         job, &KJob::resume);
+        QObject::connect(jobView, SIGNAL(cancelRequested()), this, SLOT(_k_killJob()));
+        QObject::connect(jobView, &org::kde::JobViewV2::suspendRequested, job, &KJob::suspend);
+        QObject::connect(jobView, &org::kde::JobViewV2::resumeRequested, job, &KJob::resume);
 
         d->updateDestUrl(job, jobView);
 
         if (!jobWatch) {
-            //qCDebug(KJOBWIDGETS) << "deleted out from under us when creating the dbus interface";
+            // qCDebug(KJOBWIDGETS) << "deleted out from under us when creating the dbus interface";
             jobView->terminate(QString());
             delete jobView;
             return;
@@ -227,9 +207,7 @@ void KUiServerJobTracker::resumed(KJob *job)
     jobView->setSuspended(false);
 }
 
-void KUiServerJobTracker::description(KJob *job, const QString &title,
-                                      const QPair<QString, QString> &field1,
-                                      const QPair<QString, QString> &field2)
+void KUiServerJobTracker::description(KJob *job, const QString &title, const QPair<QString, QString> &field1, const QPair<QString, QString> &field2)
 {
     if (!d->progressJobView.contains(job)) {
         return;
@@ -283,6 +261,9 @@ void KUiServerJobTracker::totalAmount(KJob *job, KJob::Unit unit, qulonglong amo
     case KJob::Directories:
         jobView->setTotalAmount(amount, QStringLiteral("dirs"));
         break;
+    case KJob::Items:
+        jobView->setTotalAmount(amount, QStringLiteral("items"));
+        break;
     }
 }
 
@@ -304,6 +285,9 @@ void KUiServerJobTracker::processedAmount(KJob *job, KJob::Unit unit, qulonglong
     case KJob::Directories:
         jobView->setProcessedAmount(amount, QStringLiteral("dirs"));
         break;
+    case KJob::Items:
+        jobView->setProcessedAmount(amount, QStringLiteral("items"));
+        break;
     }
 }
 
@@ -337,7 +321,7 @@ KSharedUiServerProxy::KSharedUiServerProxy()
     if (!bus->isServiceRegistered(QStringLiteral("org.kde.JobViewServer"))) {
         QDBusReply<void> reply = bus->startService(QStringLiteral("org.kde.kuiserver"));
         if (!reply.isValid()) {
-            qCritical() << "Couldn't start kuiserver from org.kde.kuiserver.service:" << reply.error();
+            qCCritical(KJOBWIDGETS) << "Couldn't start kuiserver from org.kde.kuiserver.service:" << reply.error();
             return;
         }
 
@@ -363,7 +347,6 @@ KSharedUiServerProxy::KSharedUiServerProxy()
 
 KSharedUiServerProxy::~KSharedUiServerProxy()
 {
-
 }
 
 org::kde::JobViewServer *KSharedUiServerProxy::uiserver()
@@ -377,9 +360,9 @@ void KSharedUiServerProxy::uiserverOwnerChanged(const QString &serviceName, cons
     Q_UNUSED(oldOwner);
 
     if (!newOwner.isEmpty()) { // registered
-        emit serverRegistered();
+        Q_EMIT serverRegistered();
     } else if (newOwner.isEmpty()) { // unregistered
-        emit serverUnregistered();
+        Q_EMIT serverUnregistered();
     }
 }
 
